@@ -1,4 +1,4 @@
-from django.conf.urls import patterns, include, url
+from django.conf.urls import patterns, url
 from rapidsms.backends.kannel.views import DeliveryReportView
 
 
