@@ -9,7 +9,7 @@ class VumiForm(BaseHttpForm):
     from_addr = forms.CharField()
     in_reply_to = forms.CharField(required=False)
     session_event = forms.CharField(required=False)
-    content = forms.CharField()
+    content = forms.CharField(required=False)
     transport_name = forms.CharField()
     transport_type = forms.CharField()
     group = forms.CharField(required=False)
