@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # vim: ai ts=4 sts=4 et sw=4
 
+from django.contrib.auth.decorators import login_required
 from django.http import HttpResponse, HttpResponseBadRequest
 from django.shortcuts import render
 from django.views.decorators.http import require_POST
@@ -8,12 +9,14 @@ from django.views.decorators.http import require_POST
 from .forms import MessageForm
 
 
+@login_required
 def messaging(request):
     return render(request, 'messaging/dashboard.html', {
         'form': MessageForm(),
     })
 
 
+@login_required
 @require_POST
 def send(request):
     try:
@@ -23,8 +26,9 @@ def send(request):
             if len(message.connections) == 1:
                 return HttpResponse('Your message was sent to 1 recipient.')
             else:
-                return HttpResponse('Your message was sent to {0} '
-                        'recipients.'.format(len(message.connections)))
+                msg = 'Your message was sent to {0} ' \
+                    'recipients.'.format(len(message.connections))
+                return HttpResponse(msg)
         else:
             return HttpResponseBadRequest(unicode(form.errors))
     except:
