@@ -17,7 +17,10 @@ from rapidsms.conf import settings
 
 
 if "django.core.context_processors.request" not in settings.TEMPLATE_CONTEXT_PROCESSORS:
-    raise ImproperlyConfigured("To use paginator tag, add 'django.core.context_processors.request' to TEMPLATE_CONTEXT_PROCESSORS")
+    raise ImproperlyConfigured(
+        "To use paginator tag, add 'django.core.context_processors.request' "
+        "to TEMPLATE_CONTEXT_PROCESSORS"
+    )
 
 
 @register.inclusion_tag("rapidsms/templatetags/paginator.html", takes_context=True)
@@ -49,20 +52,20 @@ def paginator(context, page, prefix=""):
             "link": _link(number),
             "active": (page.number == number)}
 
-    #num_border_links represent the first N pages and last N pages in the paginator
+    # num_border_links represent the first N pages and last N pages in the paginator
     num_border_links = min(settings.PAGINATOR_BORDER_LINKS, page.paginator.num_pages)
-    #num_adjacent_links represents the N pages around the current page
+    # num_adjacent_links represents the N pages around the current page
     num_adjacent_links = min(settings.PAGINATOR_ADJACENT_LINKS, page.paginator.num_pages)
     last_page_number = page.paginator.num_pages + 1
 
     pages = set([page.number])
-    #first set of border links
+    # first set of border links
     for p in range(1, num_border_links + 1):
         pages.add(p)
-    #last border links
+    # last border links
     for p in range(last_page_number - num_border_links, last_page_number):
         pages.add(p)
-    #make sure that the adjacent links do not go outside of the page range
+    # make sure that the adjacent links do not go outside of the page range
     first_adjacent = max(1, page.number - num_adjacent_links)
     last_adjacent = min(page.number + num_adjacent_links + 1, last_page_number)
     for p in range(first_adjacent, last_adjacent):
@@ -74,25 +77,25 @@ def paginator(context, page, prefix=""):
         page_links.append(_page(pages[i]))
         gap = pages[i + 1] - pages[i]
         if gap == 2:
-            #if the ellipsis would only cover 1 page, add that page.
+            # if the ellipsis would only cover 1 page, add that page.
             page_links.append(_page(pages[i] + 1))
         elif gap > 2:
-            #add an ellipsis when there is a gap in the pages.
+            # add an ellipsis when there is a gap in the pages.
             page_links.append(None)
     if pages:
         page_links.append(_page(pages[-1]))
 
     subcontext = {
-        "dom_id":     dom_id,
+        "dom_id": dom_id,
         "page_links": page_links}
 
     if page.number > 1:
         subcontext.update({
-            "prev_page_link":  _link(page.previous_page_number())})
+            "prev_page_link": _link(page.previous_page_number())})
 
     if page.number < page.paginator.num_pages:
         subcontext.update({
-            "next_page_link":  _link(page.next_page_number())})
+            "next_page_link": _link(page.next_page_number())})
 
     return subcontext
 
