@@ -2,7 +2,6 @@ import os
 
 db_name = 'test_rapidsms'
 db_engine = os.environ.get('DBENGINE', 'sqlite3')
-db_name = "rapidsms_{0}".format(os.environ.get('TESTENV', db_name))
 
 TEST_RUNNER = "django_nose.NoseTestSuiteRunner"
 
@@ -30,6 +29,7 @@ INSTALLED_APPS = [
     "django.contrib.sites",
     "django.contrib.auth",
     "django.contrib.admin",
+    "django.contrib.messages",
     "django.contrib.sessions",
     "django.contrib.staticfiles",
     "django.contrib.contenttypes",
@@ -49,6 +49,15 @@ INSTALLED_APPS = [
     "rapidsms.contrib.default",  # Should be last
 ]
 
+# Django 1.7+ emits a warning if this is not set
+MIDDLEWARE_CLASSES = (
+    'django.middleware.common.CommonMiddleware',
+    'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.middleware.csrf.CsrfViewMiddleware',
+    'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'django.contrib.messages.middleware.MessageMiddleware',
+)
+
 SITE_ID = 1
 
 SECRET_KEY = 'super-secret'
